@@ -1,58 +1,64 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-
 # This file is part of svgis.
 # https://github.com/fitnr/svgis
-
 # Licensed under the GNU General Public License v3 (GPLv3) license:
 # http://opensource.org/licenses/GPL-3.0
 # Copyright (c) 2016, Neil Freeman <contact@fakeisthenewreal.org>
-
-import unittest
 import re
+import unittest
+
 import six
+
 from svgis import draw, errors, svgis
 
 
 class DrawTestCase(unittest.TestCase):
 
-    properties = {
-        'cat': u'meow',
-        'dog': 'woof'
-    }
+    properties = {'cat': u'meow', 'dog': 'woof'}
 
     classes = [u'foo', 'cat']
 
-    lis1 = [[-110.6, 35.3], [-110.7, 35.5], [-110.3, 35.5], [-110.2, 35.1], [-110.2, 35.8], [-110.3, 35.2],
-            [-110.1, 35.8], [-110.8, 35.5], [-110.7, 35.7], [-110.1, 35.4], [-110.7, 35.1], [-110.6, 35.3]]
+    lis1 = [
+        [-110.6, 35.3],
+        [-110.7, 35.5],
+        [-110.3, 35.5],
+        [-110.2, 35.1],
+        [-110.2, 35.8],
+        [-110.3, 35.2],
+        [-110.1, 35.8],
+        [-110.8, 35.5],
+        [-110.7, 35.7],
+        [-110.1, 35.4],
+        [-110.7, 35.1],
+        [-110.6, 35.3],
+    ]
 
-    lis2 = [[-110.8, 35.3], [-110.6, 35.4], [-110.1, 35.5], [-110.1, 35.5], [-110.4, 35.2],
-            [-110.5, 35.1], [-110.5, 35.1], [-110.9, 35.8], [-110.5, 35.1], [-110.8, 35.3]]
+    lis2 = [
+        [-110.8, 35.3],
+        [-110.6, 35.4],
+        [-110.1, 35.5],
+        [-110.1, 35.5],
+        [-110.4, 35.2],
+        [-110.5, 35.1],
+        [-110.5, 35.1],
+        [-110.9, 35.8],
+        [-110.5, 35.1],
+        [-110.8, 35.3],
+    ]
 
     def setUp(self):
         self.multipolygon = {
             "properties": self.properties,
-            "geometry": {
-                "type": "MultiPolygon",
-                "id": "MultiPolygon",
-                "coordinates": [[self.lis1], [self.lis2]]
-            }
+            "geometry": {"type": "MultiPolygon", "id": "MultiPolygon", "coordinates": [[self.lis1], [self.lis2]]},
         }
         self.polygon = {
             "properties": self.properties,
-            "geometry": {
-                "type": "Polygon",
-                "id": "Polygon",
-                "coordinates": [self.lis1]
-            }
+            "geometry": {"type": "Polygon", "id": "Polygon", "coordinates": [self.lis1]},
         }
         self.multilinestring = {
             "properties": self.properties,
-            "geometry": {
-                'type': 'MultiLineString',
-                "id": "MultiLineString",
-                'coordinates': [self.lis2, self.lis2]
-            }
+            "geometry": {'type': 'MultiLineString', "id": "MultiLineString", 'coordinates': [self.lis2, self.lis2]},
         }
         self.linestring = {
             "properties": self.properties,
@@ -60,7 +66,7 @@ class DrawTestCase(unittest.TestCase):
                 'coordinates': self.lis2,
                 'type': 'LineString',
                 "id": "LineString",
-            }
+            },
         }
         self.point = {
             "properties": self.properties,
@@ -68,7 +74,7 @@ class DrawTestCase(unittest.TestCase):
                 'coordinates': (0.0, 0),
                 'type': 'Point',
                 "id": "Point",
-            }
+            },
         }
 
         self.obj = svgis.SVGIS([])
@@ -119,13 +125,8 @@ class DrawTestCase(unittest.TestCase):
         assert re.search(r'<g[^>]*id="foo"', points)
 
     def testAddClass(self):
-        geom = {
-            'coordinates': (0, 0),
-            'type': 'Point'
-        }
-        kwargs = {
-            "class": "boston"
-        }
+        geom = {'coordinates': (0, 0), 'type': 'Point'}
+        kwargs = {"class": "boston"}
         point = draw.points(geom, **kwargs)
         self.assertIsInstance(point, six.string_types)
 
@@ -135,7 +136,7 @@ class DrawTestCase(unittest.TestCase):
     def testDrawPolygonComplicated(self):
         coordinates = [
             [(0.0, 0.0), (10.0, 0.0), (10.0, 10.0), (0.0, 10.0), (0.0, 0.0)],
-            [(4.0, 4.0), (4.0, 5.0), (5.0, 5.0), (5.0, 4.0), (4.0, 4.0)]
+            [(4.0, 4.0), (4.0, 5.0), (5.0, 5.0), (5.0, 4.0), (4.0, 4.0)],
         ]
 
         polygon = draw.polygon(coordinates)
@@ -158,7 +159,7 @@ class DrawTestCase(unittest.TestCase):
                 self.linestring['geometry'],
                 self.point['geometry'],
                 self.multipolygon['geometry'],
-                self.multilinestring['geometry']
+                self.multilinestring['geometry'],
             ],
         }
         a = draw.geometry(gc, id='cats')
