@@ -1,22 +1,21 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-
 # This file is part of svgis.
 # https://github.com/fitnr/svgis
-
 # Licensed under the GNU General Public License v3 (GPLv3) license:
 # http://opensource.org/licenses/GPL-3.0
 # Copyright (c) 2016, Neil Freeman <contact@fakeisthenewreal.org>
 import unittest
 from xml.dom import minidom
-from svgis import style, svg
+
 import six
 
+from svgis import style, svg
+
 
 class SvgTestCase(unittest.TestCase):
-
     def setUp(self):
-        self.file = 'tests/test_data/test.svg'
+        self.file = 'tests/fixtures/test.svg'
         self.newstyle = 'stroke {color:red;}'
 
     def test_rescale(self):
@@ -27,14 +26,13 @@ class SvgTestCase(unittest.TestCase):
 
     def test_create(self):
         s = svg.drawing((100, 100), [])
-        assert isinstance(s, six.string_types)
+        self.assertIsInstance(s, six.string_types)
 
         s = svg.drawing((100, 100), [])
-        assert isinstance(s, six.string_types)
+        self.assertIsInstance(s, six.string_types)
 
         s = svg.drawing((100, 100), [], style=self.newstyle)
-
-        assert self.newstyle in s
+        self.assertIn(self.newstyle, s)
 
     def testGroup(self):
         g = svg.group()
@@ -44,34 +42,41 @@ class SvgTestCase(unittest.TestCase):
         self.assertIn('transform="translate(10,10)"', g)
 
         g = svg.group(transform="scale(10)")
-        assert 'transform="scale(10)"' in g
+        self.assertIn('transform="scale(10)"', g)
 
     def testAttribs(self):
-        args = {
-            'transform': 'translate(10, 10)',
-            'fill': 'black'
-        }
-        assert 'transform="translate(10, 10)"' in svg.toattribs(**args)
-        assert 'fill="black"' in svg.toattribs(**args)
+        args = {'transform': 'translate(10, 10)', 'fill': 'black'}
+        self.assertIn('transform="translate(10, 10)"', svg.toattribs(**args))
+        self.assertIn('fill="black"', svg.toattribs(**args))
 
     def testDrawCircle(self):
         point = svg.circle((0.0, 0.0), r=2)
-        assert isinstance(point, six.string_types)
+        self.assertIsInstance(point, six.string_types)
         assert 'r="2"' in point
         self.assertIn('cy="0.0"', point)
         assert 'cx="0.0"' in point
 
     def testDrawPath(self):
         coordinates = [
-            (0.0, 0.0), (10.0, 0.0), (10.0, 10.0), (0.0, 10.0), (0.0, 0.0), 'M',
-            (4.0, 4.0), (4.0, 5.0), (5.0, 5.0), (5.0, 4.0), (4.0, 4.0), 'Z'
+            (0.0, 0.0),
+            (10.0, 0.0),
+            (10.0, 10.0),
+            (0.0, 10.0),
+            (0.0, 0.0),
+            'M',
+            (4.0, 4.0),
+            (4.0, 5.0),
+            (5.0, 5.0),
+            (5.0, 4.0),
+            (4.0, 4.0),
+            'Z',
         ]
 
         path = svg.path(coordinates)
-        assert isinstance(path, six.string_types)
-        assert ' M ' in path
-        assert 'Z"' in path
-        assert '10.0,0.0' in path
+        self.assertIsInstance(path, six.string_types)
+        self.assertIn(' M ', path)
+        self.assertIn('Z"', path)
+        self.assertIn('10.0,0.0', path)
 
     def assertPartsIn(self, fixture, test):
         for f in fixture:
